OpenRPA

# Studio

Backend: win32 or uia

## OpenRPA

##### by UnicodeLabs

Select element in the tree to see hierarchy list

Edit GUI selector
[{depth_start: <1+>, depth_end: <1+>, index|ctrl_index: <0+>, title: <str>, title_re: <str re pattern>, rich_text: <str>, rich_text_re: <str re pattern>, class_name: <str>, class_name_re: <str re pattern>, friendly_class_name: <str>, friendly_class_name_re: <str re pattern>, control_type: <str>, control_type_re: <str re pattern>, is_enabled: <bool>, is_visible: <bool>}]
Validate Result
Select action
Select action
Set arguments

Result
Other activity
Sleep 3s Show dialog YesNo
Module name
Activity name
Argument list
Argument dict
Code list

Here is the message text!

No
Yes
Code list import
Insert your JSON specification here.

Cancel
Parse